models/point_ecosystem_user library
Classes
- PointEcosystemUserModel
- User model for managing point login bonuses, etc.
Typedefs
- PointEcosystemUserModelCollection = _$PointEcosystemUserModelCollection
- Collection class for storing PointEcosystemUserModel.
- PointEcosystemUserModelDocument = _$PointEcosystemUserModelDocument
- Document class for storing PointEcosystemUserModel.
- PointEcosystemUserModelInitialCollection = _$PointEcosystemUserModelInitialCollection
-
Class for defining initial values to be passed to
initialValueofRuntimeModelAdapter. - PointEcosystemUserModelKeys = _$PointEcosystemUserModelKeys
- Enum of the name of the value defined in PointEcosystemUserModel.
- PointEcosystemUserModelMirrorCollection = _$PointEcosystemUserModelMirrorCollection
- Collection class for storing PointEcosystemUserModel.
- PointEcosystemUserModelMirrorDocument = _$PointEcosystemUserModelMirrorDocument
- Document class for storing PointEcosystemUserModel.
- PointEcosystemUserModelMirrorInitialCollection = _$PointEcosystemUserModelMirrorInitialCollection
-
Class for defining initial values to be passed to
initialValueofRuntimeModelAdapter. - PointEcosystemUserModelMirrorRefPath = _$PointEcosystemUserModelMirrorRefPath
- It can be defined as an empty ModelRef<PointEcosystemUserModel>.
-
PointEcosystemUserModelRef
= ModelRef<
PointEcosystemUserModel> ? - Alias for ModelRef<PointEcosystemUserModel>.
- PointEcosystemUserModelRefPath = _$PointEcosystemUserModelRefPath
- It can be defined as an empty ModelRef<PointEcosystemUserModel>.