PointEcosystemUserModel class
User model for managing point login bonuses, etc.
ポイントのログインボーナスなどを管理するためのユーザーモデル。
- Annotations
-
- @freezed
- @formValue
- @immutable
- @CollectionModelPath.new(PointEcosystemUserModel.path)
Constructors
- PointEcosystemUserModel({ModelTimestamp? lastDate, @Default.new(0) int continuousCount})
-
User model for managing point login bonuses, etc.
constfactory
-
PointEcosystemUserModel.fromJson(Map<
String, Object?> json) -
factory
Properties
- continuousCount → int
-
no setterinherited
-
copyWith
→ $PointEcosystemUserModelCopyWith<
PointEcosystemUserModel> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastDate → ModelTimestamp?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- collection → const _$PointEcosystemUserModelCollectionQuery
- Query for collection.
- document → const _$PointEcosystemUserModelDocumentQuery
- Query for document.
- form → const _$PointEcosystemUserModelFormQuery
- Query for form value.
- path → const String
- Model path.